@@ -560,14 +560,23 @@ class Model(proto.Message):
             class FeatureValue(proto.Message):
                 r"""Representative value of a single feature within the cluster.
 
+                This message has `oneof`_ fields (mutually exclusive fields).
+                For each oneof, at most one member field can be set at the same time.
+                Setting any member of the oneof automatically clears all other
+                members.
+
+                .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
                 Attributes:
                     feature_column (str):
                         The feature column name.
                     numerical_value (google.protobuf.wrappers_pb2.DoubleValue):
                         The numerical feature value. This is the
                         centroid value for this feature.
+                        This field is a member of `oneof`_ ``value``.
                     categorical_value (google.cloud.bigquery_v2.types.Model.ClusteringMetrics.Cluster.FeatureValue.CategoricalValue):
                         The categorical feature value.
+                        This field is a member of `oneof`_ ``value``.
                 """
 
                 class CategoricalValue(proto.Message):
@@ -784,23 +793,36 @@ class Model(proto.Message):
         data was used during training. These are not present for
         imported models.
 
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             regression_metrics (google.cloud.bigquery_v2.types.Model.RegressionMetrics):
                 Populated for regression models and explicit
                 feedback type matrix factorization models.
+                This field is a member of `oneof`_ ``metrics``.
             binary_classification_metrics (google.cloud.bigquery_v2.types.Model.BinaryClassificationMetrics):
                 Populated for binary
                 classification/classifier models.
+                This field is a member of `oneof`_ ``metrics``.
             multi_class_classification_metrics (google.cloud.bigquery_v2.types.Model.MultiClassClassificationMetrics):
                 Populated for multi-class
                 classification/classifier models.
+                This field is a member of `oneof`_ ``metrics``.
             clustering_metrics (google.cloud.bigquery_v2.types.Model.ClusteringMetrics):
                 Populated for clustering models.
+                This field is a member of `oneof`_ ``metrics``.
             ranking_metrics (google.cloud.bigquery_v2.types.Model.RankingMetrics):
                 Populated for implicit feedback type matrix
                 factorization models.
+                This field is a member of `oneof`_ ``metrics``.
             arima_forecasting_metrics (google.cloud.bigquery_v2.types.Model.ArimaForecastingMetrics):
                 Populated for ARIMA models.
+                This field is a member of `oneof`_ ``metrics``.
         """
 
         regression_metrics = proto.Field(
